<?php
namespace Opencart\Catalog\Controller\Extension\Klix\Payment;

use PurchaseObject;

require_once(DIR_EXTENSION . 'klix/system/library/PurchaseObject.php');

class Klix extends \Opencart\System\Engine\Controller {
	private $separator = '';
	private $version='1.0.2';
	
	public function __construct($registry) {
        parent::__construct($registry);

		if (VERSION >= '4.0.2.0') {
			$this->separator = '.';
		} else {
			$this->separator = '|';
		}
    }
	
	public function index(): string {

		
		$this->load->model('extension/klix/payment/klix');
		$klix_settings = $this->model_setting_setting->getSetting('payment_klix');

		$klix_payment_methods=$this->model_extension_klix_payment_klix->getPaymentMethodsFromAPI();
		$grouped_payment_methods=$this->model_extension_klix_payment_klix->getGroupedPaymentMethods($klix_payment_methods);
		$data['klix_status']=$klix_settings['payment_klix_status'];
		$data['klix_payment_methods']=$klix_payment_methods;
		$data['klix_grouped_payment_methods']=$grouped_payment_methods;
		$data['selected_country']=$this->session->data['shipping_address']['iso_code_2'];
		$data['klix_payment_checkout_title']='Klix payments';

		$data['separator'] = $this->separator;
	
		return $this->load->view('extension/klix/payment/klix', $data);
		
		return '';
	}
	

	public function confirm(): void {
		
		$this->load->language('extension/klix/payment/klix');
		$this->load->model('extension/klix/payment/klix');

		$this->load->model('checkout/order');
		$this->load->model('account/order');
		$this->load->model('localisation/language');
		$this->load->model('localisation/order_status');


		$order_info = $this->model_checkout_order->getOrder($this->session->data['order_id']);

		$purchaseObject=new PurchaseObject();
		

		$purchaseObject->client['email']=$order_info['email'];
		$purchaseObject->client['phone']=$order_info['telephone'];
		$purchaseObject->client['full_name']=$order_info['shipping_firstname'].' '.$order_info['shipping_lastname'];
		$purchaseObject->client['street_address']=$order_info['shipping_address_1'].' '.$order_info['shipping_address_2'];
		$purchaseObject->client['city']=$order_info['shipping_city'];
		$purchaseObject->client['zip_code']=$order_info['shipping_postcode'];
		$purchaseObject->client['country']=$order_info['shipping_country'];
		$purchaseObject->client['state']=$order_info['shipping_zone'];


		$order_products = $this->model_account_order->getProducts($this->session->data['order_id']);
		$notes='';
		foreach ($order_products as $product) {
			$notes .=
					$product['name'] . " " . $product['model'] .
					" x " . $product['quantity'] . '; ';
		}
		$purchaseObject->purchase['notes']=$notes;

		$purchaseObject->purchase['language']=$this->language->get('code');
		$product=[];
		$product['name']='Payment';
		$product['price']=$order_info['total']*100;
		$purchaseObject->purchase['products'][]=$product;
		$purchaseObject->brand_id=$this->config->get('payment_klix_brand_id');
		$purchaseObject->reference=$this->session->data['order_id'];
		$url=$this->request->server['HTTP_ORIGIN'].$this->request->server['PHP_SELF'];
		$purchaseObject->success_redirect=$url.'?route=extension/klix/payment/klix.success'.'&order_id='.$this->session->data['order_id'];
		$purchaseObject->success_callback=$url.'?route=extension/klix/payment/klix.success'.'&order_id='.$this->session->data['order_id'];
		$purchaseObject->cancel_redirect=$url.'?route=extension/klix/payment/klix.cancel'.'&order_id='.$this->session->data['order_id'];
		$purchaseObject->failure_redirect=$url.'?route=extension/klix/payment/klix.failure'.'&order_id='.$this->session->data['order_id'];
		$purchaseObject->platform='opencart';
		$purchaseObject->creator_agent='OpenCart module: v'.$this->version;


		$createdPurchase=$this->model_extension_klix_payment_klix->createPurchase((array)$purchaseObject);
		
		$order_statuses = $this->model_localisation_order_status->getOrderStatuses();
		$processing_status_id=null;
		foreach($order_statuses as $order_status)
		{
			if($order_status['name']=='Processing') {
				$processing_status_id=$order_status['order_status_id'];
			}
		}

		$this->model_checkout_order->addHistory($this->session->data['order_id'], $processing_status_id);
		
		$data=json_encode([
			'purchase_id'=>$createdPurchase['id'],
			'payment_method'=>$_POST['payment_method']
		]);

		$this->model_extension_klix_payment_klix->updateOrderPaymentInfo($this->session->data['order_id'],$data);

		header('Location: ' . $createdPurchase['checkout_url'].'?preferred='.$_POST['payment_method'], true, 302);
	}
			
	public function success():void
	{
		$this->load->language('extension/klix/payment/klix');
		$this->load->model('checkout/order');
		$this->load->model('extension/klix/payment/klix');
		$this->load->model('localisation/order_status');

		$order=$this->model_checkout_order->getOrder($_GET['order_id']);

		$purchase=$this->model_extension_klix_payment_klix->getPurchase($order['payment_custom_field']['purchase_id']);
		
		if($purchase['status']=='paid' && $order['order_status_id']==2)
		{
			$order_statuses = $this->model_localisation_order_status->getOrderStatuses();
			$processed_status_id=null;
			foreach($order_statuses as $order_status)
			{
				if($order_status['name']=='Processed') {
					$processed_status_id=$order_status['order_status_id'];
				}
			}

			$this->model_checkout_order->addHistory($_GET['order_id'], $processed_status_id,'',true);
			$data=json_encode([
				'purchase_id'=>$purchase['id'],
				'payment_method'=>$purchase['transaction_data']['payment_method'],
				'refund_availability'=>$purchase['refund_availability']
			]);
			$this->model_extension_klix_payment_klix->updateOrderPaymentInfo($_GET['order_id'],$data);

		}
		Header("Location: ".$this->url->link('checkout/success', 'language=' . $this->config->get('config_language'), true));
	}
}